@@ -252,31 +252,31 @@ static void set_port_info(ib_portid_t * dest, uint8_t * data, int portnum,
 	show_port_info(dest, data, portnum, espeed_cap, is_switch);
 }
 
-static void get_ext_port_info(ib_portid_t * dest, uint8_t * data, int portnum)
+static void get_mlnx_ext_port_info(ib_portid_t * dest, uint8_t * data, int portnum)
 {
 	if (!smp_query_via(data, dest, IB_ATTR_MLNX_EXT_PORT_INFO,
 			   portnum, 0, srcport))
 		IBEXIT("smp query ext portinfo failed");
 }
 
-static void show_ext_port_info(ib_portid_t * dest, uint8_t * data, int portnum)
+static void show_mlnx_ext_port_info(ib_portid_t * dest, uint8_t * data, int portnum)
 {
 	char buf[256];
 
 	mad_dump_mlnx_ext_port_info(buf, sizeof buf, data, IB_SMP_DATA_SIZE);
 
-	printf("# Extended Port info: %s port %d\n%s", portid2str(dest),
+	printf("# MLNX ext Port info: %s port %d\n%s", portid2str(dest),
 	       portnum, buf);
 }
 
-static void set_ext_port_info(ib_portid_t * dest, uint8_t * data, int portnum)
+static void set_mlnx_ext_port_info(ib_portid_t * dest, uint8_t * data, int portnum)
 {
 	if (!smp_set_via(data, dest, IB_ATTR_MLNX_EXT_PORT_INFO,
 			 portnum, 0, srcport))
-		IBEXIT("smp set ext portinfo failed");
+		IBEXIT("smp set MLNX ext portinfo failed");
 
-	printf("\nAfter ExtendedPortInfo set:\n");
-	show_ext_port_info(dest, data, portnum);
+	printf("\nAfter MLNXExtendedPortInfo set:\n");
+	show_mlnx_ext_port_info(dest, data, portnum);
 }
 
 static int get_link_width(int lwe, int lws)
@@ -447,40 +447,40 @@ int main(int argc, char **argv)
 			val = strtoull(argv[i], 0, 0);
 			switch (j) {
 			case SPEED:
-				if (val < 0 || val > 15)
+				if (val > 15)
 					IBEXIT("invalid speed value %ld", val);
 				break;
 			case ESPEED:
-				if (val < 0 || val > 31)
+				if (val > 31)
 					IBEXIT("invalid extended speed value %ld", val);
 				break;
 			case FDR10SPEED:
-				if (val < 0 || val > 1)
+				if (val > 1)
 					IBEXIT("invalid fdr10 speed value %ld", val);
 				break;
 			case WIDTH:
-				if (val < 0 || (val > 15 && val != 255))
+				if ((val > 15 && val != 255))
 					IBEXIT("invalid width value %ld", val);
 				break;
 			case VLS:
-				if (val <= 0 || val > 5)
+				if (val == 0 || val > 5)
 					IBEXIT("invalid vls value %ld", val);
 				break;
 			case MTU:
-				if (val <= 0 || val > 5)
+				if (val == 0 || val > 5)
 					IBEXIT("invalid mtu value %ld", val);
 				break;
 			case LID:
-				if (val <= 0 || val >= 0xC000)
+				if (val == 0 || val >= 0xC000)
 					IBEXIT("invalid lid value 0x%lx", val);
 				break;
 			case SMLID:
-				if (val <= 0 || val >= 0xC000)
+				if (val == 0 || val >= 0xC000)
 					IBEXIT("invalid smlid value 0x%lx",
 						val);
 				break;
 			case LMC:
-				if (val < 0 || val > 7)
+				if (val > 7)
 					IBEXIT("invalid lmc value %ld", val);
 				break;
 			case MKEY:
@@ -497,11 +497,11 @@ int main(int argc, char **argv)
 				/* All 64-bit values are legal */
 				break;
 			case MKEYLEASE:
-				if (val < 0 || val > 0xFFFF)
+				if (val > 0xFFFF)
 					IBEXIT("invalid mkey lease time %ld", val);
 				break;
 			case MKEYPROT:
-				if (val < 0 || val > 3)
+				if (val > 3)
 					IBEXIT("invalid mkey protection bit setting %ld", val);
 			}
 			*port_args[j].val = val;
@@ -528,8 +528,8 @@ int main(int argc, char **argv)
 	espeed_cap = get_port_info(&portid, data, portnum, is_switch);
 	show_port_info(&portid, data, portnum, espeed_cap, is_switch);
 	if (is_mlnx_ext_port_info_supported(devid)) {
-		get_ext_port_info(&portid, data2, portnum);
-		show_ext_port_info(&portid, data2, portnum);
+		get_mlnx_ext_port_info(&portid, data2, portnum);
+		show_mlnx_ext_port_info(&portid, data2, portnum);
 	}
 
 	if (port_op != QUERY || changed) {
@@ -600,7 +600,7 @@ int main(int argc, char **argv)
 			mad_set_field(data2, 0,
 				      IB_MLNX_EXT_PORT_LINK_SPEED_ENABLED_F,
 				      fdr10);
-			set_ext_port_info(&portid, data2, portnum);
+			set_mlnx_ext_port_info(&portid, data2, portnum);
 		}
 
 		if (port_args[MKEY].set)
@@ -678,13 +678,13 @@ int main(int argc, char **argv)
 							peerlocalportnum,
 							is_peer_switch);
 			if (is_mlnx_ext_port_info_supported(rem_devid))
-				get_ext_port_info(&peerportid, data2,
-						  peerlocalportnum);
+				get_mlnx_ext_port_info(&peerportid, data2,
+						       peerlocalportnum);
 			show_port_info(&peerportid, data, peerlocalportnum,
 				       peer_espeed_cap, is_peer_switch);
 			if (is_mlnx_ext_port_info_supported(rem_devid))
-				show_ext_port_info(&peerportid, data2,
-						   peerlocalportnum);
+				show_mlnx_ext_port_info(&peerportid, data2,
+							peerlocalportnum);
 
 			mad_decode_field(data, IB_PORT_LINK_WIDTH_ENABLED_F,
 					 &peerlwe);
